pub trait IntoString {
// Required method
fn into_string(self) -> String;
}Expand description
Converts the implementing type into a String by consuming it.
Required Methods
Sourcefn into_string(self) -> String
fn into_string(self) -> String
Consumes the implementing type and converts it into a String.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".